@@ -430,11 +430,8 @@ feed_panel_popup_item (GtkWidget*     menu,
                        gpointer       callback,
                        FeedPanel*     panel)
 {
-    const gchar* uri;
     GtkWidget* menuitem;
 
-    uri = katze_item_get_uri (item);
-
     menuitem = gtk_image_menu_item_new_from_stock (stock_id, NULL);
     if (label)
         gtk_label_set_text_with_mnemonic (GTK_LABEL (gtk_bin_get_child (
@@ -625,7 +622,7 @@ webview_button_press_event_cb (GtkWidget*      widget,
                                GdkEventButton* event)
 {
     /* Disable the popup menu */
-    return (event->button == 3);
+    return MIDORI_EVENT_CONTEXT_MENU (event);
 }
 
 static gboolean
@@ -847,7 +844,11 @@ feed_panel_init (FeedPanel* panel)
     gtk_widget_show (treeview);
 
     webview = webkit_web_view_new ();
+#if GTK_CHECK_VERSION(3,0,0)
+    font_desc = gtk_style_context_get_font(gtk_widget_get_style_context(treeview), GTK_STATE_FLAG_NORMAL);
+#else
     font_desc = treeview->style->font_desc;
+#endif
     family = pango_font_description_get_family (font_desc);
     size = pango_font_description_get_size (font_desc) / PANGO_SCALE;
     settings = webkit_web_settings_new ();
