@@ -212,7 +212,11 @@ katze_http_auth_session_authenticate_cb (SoupSession*   session,
 
     dialog = gtk_dialog_new_with_buttons (_("Authentication Required"),
         NULL,
+#if GTK_CHECK_VERSION(3,0,0)
+        GTK_DIALOG_DESTROY_WITH_PARENT,
+#else
         GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR,
+#endif
         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
         GTK_STOCK_OK, GTK_RESPONSE_OK,
         NULL);
