@@ -90,6 +90,7 @@ struct _MidoriWebSettings
     gboolean enable_dns_prefetching;
     #endif
     gboolean strip_referer;
+    gboolean flash_window_on_bg_tabs;
 };
 
 struct _MidoriWebSettingsClass
@@ -140,6 +141,7 @@ enum
     PROP_OPEN_TABS_IN_THE_BACKGROUND,
     PROP_OPEN_TABS_NEXT_TO_CURRENT,
     PROP_OPEN_POPUPS_IN_TABS,
+    PROP_FLASH_WINDOW_ON_BG_TABS,
 
     PROP_AUTO_LOAD_IMAGES,
     PROP_ENABLE_SCRIPTS,
@@ -167,7 +169,7 @@ enum
     PROP_CLEAR_PRIVATE_DATA,
     PROP_CLEAR_DATA,
     PROP_ENABLE_DNS_PREFETCHING,
-    PROP_STRIP_REFERER
+    PROP_STRIP_REFERER,
 };
 
 GType
@@ -288,7 +290,8 @@ midori_identity_get_type (void)
     if (!type)
     {
         static const GEnumValue values[] = {
-         { MIDORI_IDENT_MIDORI, "MIDORI_IDENT_MIDORI", N_("Midori") },
+         { MIDORI_IDENT_MIDORI, "MIDORI_IDENT_MIDORI", N_("_Automatic") },
+         { MIDORI_IDENT_GENUINE, "MIDORI_IDENT_GENUINE", N_("Midori") },
          { MIDORI_IDENT_SAFARI, "MIDORI_IDENT_SAFARI", N_("Safari") },
          { MIDORI_IDENT_IPHONE, "MIDORI_IDENT_IPHONE", N_("iPhone") },
          { MIDORI_IDENT_FIREFOX, "MIDORI_IDENT_FIREFOX", N_("Firefox") },
@@ -715,8 +718,13 @@ midori_web_settings_class_init (MidoriWebSettingsClass* class)
                                      "enable-plugins",
                                      _("Enable Netscape plugins"),
                                      _("Enable embedded Netscape plugin objects"),
+    #ifdef G_OS_WIN32
+                                     FALSE,
+                                     G_PARAM_READABLE));
+    #else
                                      TRUE,
                                      flags));
+    #endif
     /* Override properties to override defaults */
     g_object_class_install_property (gobject_class,
                                      PROP_ENABLE_DEVELOPER_EXTRAS,
@@ -763,6 +771,14 @@ midori_web_settings_class_init (MidoriWebSettingsClass* class)
                                                            TRUE,
                                                            flags));
     #endif
+    g_object_class_install_property (gobject_class,
+                                     PROP_FLASH_WINDOW_ON_BG_TABS,
+                                     g_param_spec_boolean (
+                                     "flash-window-on-new-bg-tabs",
+                                     _("Flash window on background tabs"),
+                                     _("Flash the browser window if a new tab was opened in the background"),
+                                     FALSE,
+                                     flags));
 
     /**
      * MidoriWebSettings:zoom-text-and-images:
@@ -1081,7 +1097,8 @@ get_sys_name (void)
 #endif
 
 static gchar*
-generate_ident_string (MidoriIdentity identify_as)
+generate_ident_string (MidoriWebSettings* web_settings,
+                       MidoriIdentity     identify_as)
 {
     const gchar* platform =
     #if HAVE_HILDON
@@ -1118,12 +1135,19 @@ generate_ident_string (MidoriIdentity identify_as)
     const int webcore_major = WEBKIT_USER_AGENT_MAJOR_VERSION;
     const int webcore_minor = WEBKIT_USER_AGENT_MINOR_VERSION;
 
+    #if WEBKIT_CHECK_VERSION (1, 1, 18)
+    g_object_set (web_settings, "enable-site-specific-quirks",
+        identify_as != MIDORI_IDENT_GENUINE, NULL);
+    #endif
+
     switch (identify_as)
     {
-    case MIDORI_IDENT_MIDORI:
+    case MIDORI_IDENT_GENUINE:
         return g_strdup_printf ("Mozilla/5.0 (%s %s) AppleWebKit/%d.%d+ %s",
             platform, os, webcore_major, webcore_minor, appname);
+    case MIDORI_IDENT_MIDORI:
     case MIDORI_IDENT_SAFARI:
+        g_object_set (web_settings, "enable-site-specific-quirks", TRUE, NULL);
         return g_strdup_printf ("Mozilla/5.0 (Macintosh; U; Intel Mac OS X; %s) "
             "AppleWebKit/%d+ (KHTML, like Gecko) Version/5.0 Safari/%d.%d+ %s",
             lang, webcore_major, webcore_major, webcore_minor, appname);
@@ -1350,7 +1374,7 @@ midori_web_settings_set_property (GObject*      object,
         web_settings->identify_as = g_value_get_enum (value);
         if (web_settings->identify_as != MIDORI_IDENT_CUSTOM)
         {
-            gchar* string = generate_ident_string (web_settings->identify_as);
+            gchar* string = generate_ident_string (web_settings, web_settings->identify_as);
             katze_assign (web_settings->ident_string, string);
             g_object_set (web_settings, "user-agent", string, NULL);
         }
@@ -1380,6 +1404,9 @@ midori_web_settings_set_property (GObject*      object,
     case PROP_STRIP_REFERER:
         web_settings->strip_referer = g_value_get_boolean (value);
         break;
+    case PROP_FLASH_WINDOW_ON_BG_TABS:
+        web_settings->flash_window_on_bg_tabs = g_value_get_boolean (value);
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
@@ -1607,7 +1634,7 @@ midori_web_settings_get_property (GObject*    object,
     case PROP_USER_AGENT:
         if (!g_strcmp0 (web_settings->ident_string, ""))
         {
-            gchar* string = generate_ident_string (web_settings->identify_as);
+            gchar* string = generate_ident_string (web_settings, web_settings->identify_as);
             katze_assign (web_settings->ident_string, string);
         }
         g_value_set_string (value, web_settings->ident_string);
@@ -1629,6 +1656,9 @@ midori_web_settings_get_property (GObject*    object,
     case PROP_STRIP_REFERER:
         g_value_set_boolean (value, web_settings->strip_referer);
         break;
+    case PROP_FLASH_WINDOW_ON_BG_TABS:
+        g_value_set_boolean (value, web_settings->flash_window_on_bg_tabs);
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
