@@ -13,12 +13,6 @@
 #ifndef __SOKOKE_H__
 #define __SOKOKE_H__ 1
 
-/* Common behavior modifiers */
-#define MIDORI_MOD_NEW_WINDOW(state) (state & GDK_SHIFT_MASK)
-#define MIDORI_MOD_NEW_TAB(state) (state & GDK_CONTROL_MASK)
-#define MIDORI_MOD_BACKGROUND(state) (state & GDK_SHIFT_MASK)
-#define MIDORI_MOD_SCROLL(state) (state & GDK_CONTROL_MASK)
-
 #include <JavaScriptCore/JavaScript.h>
 #include <midori/midori-websettings.h>
 
@@ -217,6 +211,9 @@ sokoke_register_stock_items             (void);
 const gchar*
 sokoke_set_config_dir                   (const gchar*    new_config_dir);
 
+gboolean
+sokoke_is_app_or_private                (void);
+
 gboolean
 sokoke_remove_path                      (const gchar*    path,
                                          gboolean        ignore_errors);
@@ -225,17 +222,15 @@ gchar*
 sokoke_find_config_filename             (const gchar*    folder,
                                          const gchar*    filename);
 
+gchar*
+sokoke_find_lib_path                    (const gchar*    folder);
+
 gchar*
 sokoke_find_data_filename               (const gchar*    filename);
 
 gchar**
 sokoke_get_argv                         (gchar**         argument_vector);
 
-#if !WEBKIT_CHECK_VERSION (1, 1, 14)
-SoupServer*
-sokoke_get_res_server                   (void);
-#endif
-
 gchar*
 sokoke_replace_variables                (const gchar* template,
                                          const gchar* variable_first, ...);
